# Changelog

**23.5.10 (2023-05-10)**
* Sorted shell scripts in by OS
* Added script to update all supported target packages
* Updated linting

**23.5.9 (2023-05-09)**
* Dynamically imported package dependency version of this package to avoid forgetting to update it

**23.5.8 (2023-05-09)**
* Improved UX of template rendering command
* Updated meta docs how to create a new package

**23.5.7 (2023-05-09)**
* Updated docs about package dependency to updater

**23.5.6 (2023-05-09)**
* Updated project readme
* Updated package readme template
* Added UNIX script for local setup

**23.5.5 (2023-05-04)**
* Django 4.2
* Linter updates

**23.5.4 (2023-05-04)**
* Improved documentation
* Added further code quality templates

**23.5.3 (2023-05-04)**
* Improved rendered readme file

**23.5.2 (2023-05-03)**
* Templates render a trailing newline (to conform with Python linting)

**23.5.1 (2023-05-03)**
* Initial release
